pilas.depurador

Package pilas :: Module depurador |
[hide private]
[frames] | no frames]

# Module depurador

source code

Classes | [hide private]
| DepuradorDeshabilitado
| Depurador Esta clase permite hacer depuraciones visuales.
| ModoDepurador
| ModoWidgetLog
| ModoInformacionDeSistema
| ModoPuntosDeControl
| ModoRadiosDeColision
| ModoArea
| ModoFisica
| ModoPosicion

Variables | [hide private]
| __package__ = ``'``pilas``'``
| e = `ImportError('No module named PyQt4',)`